#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mueval
version:              0.9.3
visibility:           public
id:                   mueval-0.9.3-3BlkuQTivrz7vjKCkZ4BqY
key:                  mueval-0.9.3-3BlkuQTivrz7vjKCkZ4BqY
license:              BSD-3-Clause
maintainer:           Gwern <gwern@gwern.net>
author:               Gwern
homepage:             https://github.com/gwern/mueval
synopsis:             Safely evaluate pure Haskell expressions
description:
    Mueval is a Haskell interpreter. It
    uses the GHC API to evaluate arbitrary Haskell expressions.
    Importantly, mueval takes many precautions to defang and avoid \"evil\"
    code.  It uses resource limits, whitelisted modules and Safe Haskell,
    special Show instances for IO, threads, processes, and changes of directory
    to sandbox the Haskell code.

    It is, in short, intended to be a standalone version of Lambdabot'\''s famous
    evaluation functionality. For examples and explanations, please see the README file.

    Mueval is POSIX-only.

category:             Development, Language
abi:                  00fac99904859972089e346b76afb7fe
exposed:              True
exposed-modules:
    Mueval.ArgsParse Mueval.Context Mueval.Interpreter Mueval.Parallel
    Mueval.Resources

import-dirs:          /usr/lib/ghc-8.10.5/site-local/mueval-0.9.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/mueval-0.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/mueval-0.9.3
hs-libraries:         HSmueval-0.9.3-3BlkuQTivrz7vjKCkZ4BqY
depends:
    Cabal-3.2.1.0 QuickCheck-2.14.2-AlBcjlnVb6HBYuJ8lOviFD
    base-4.14.2.0 containers-0.6.4.1 directory-1.3.6.0
    extensible-exceptions-0.1.1.4-9nRdO96RVgFCedKm18TbaI
    filepath-1.4.2.1 hint-0.9.0.4-LK4O9xhZAogDQ988RpN1lj mtl-2.2.2
    process-1.6.9.0 show-0.6-xw8fttLU9n1XuDqN9KqbA
    simple-reflect-0.3.3-C3REZ52VTBC6wXIpKK13lR unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-mueval/html/mueval.haddock
haddock-html:         /usr/share/doc/haskell-mueval/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

